package cz.muni.fi.pb162.files;

import java.io.File;
import java.io.IOException;

/**
 * Na prístup k fyzickým súborom na disku je používaná trieda File
 * File nie je dátová štruktúra, ktorá by niesla obsah súboru
 * Je to abstraktná reprezentácia súborov a priečinkov
 * Je platformovo nezávislá
 */
public class Demo {
    public static void main(String[] args) throws IOException {

        // základný priečinok, z ktorého sa určuje relatívna cesta je ten kde sa nachádza pom.xml
        // trieda File môže reprezentovať súbor aj priečinok
        // vytvoriť novú inštanciu triedy File môžeme viacerými spôsobmi

        // špecifikovaním relatívnej cesty k súboru
        // je možné využiť aj absolútnu cestu, nie je to však úplne vhodné pre prenositeľnosť programu
        File directory = new File("files");

        // špecifikovaním rodičovského priečinku (objektom triedy File) a názvu súboru alebo priečinku
        File file = new File(directory, "test.txt");

        // špecifikovaním rodičovského priečinku (pomocou Stringu) a názvu súboru alebo priečinku
        File fileViaString = new File("files", "example.txt");

        //odkaz na neexistujúci súbor
        File notExisting = new File(directory, "not_existing.txt");

        // ďalej nájdete ukážky použitia niektorých metód triedy file

        // ak chceme zistiť či existuje reálny súbor, na ktorý ukazuje objekt triedy File, použijeme metódu exists()
        System.out.println("Existuje súbor test.txt: " + file.exists()); // true
        System.out.println("Existuje súbor not_existing.txt: " + notExisting.exists()); // false

        // ak chceme zistiť či ide o súbor, použijeme metódu isFile();
        System.out.println("Je test.txt súbor: " + file.isFile());

        // ak chceme zistiť či ide o priečinok, použijeme metódu isDirectory();
        System.out.println("Je files priečinok: " + directory.isDirectory());

        // ak chceme získať meno súboru alebo priečinku, použijeme metódu getName()
        System.out.println("Objekt directory odkazuje na priečinok s názvom: " + directory.getName());
        System.out.println("Objekt file odkazuje na súbor s názvom: " + file.getName());

        // ak chceme získať relatívnu cestu k súboru alebo priečinku, použijeme metódu getPath()
        System.out.println("Relatívna cesta, na ktorú odkazuje objekt file je: " + file.getPath());

        // ak chceme získať absolútnu cestu k súboru alebo priečinku, použijeme metódu getAbsolutePath()
        System.out.println("Absolútna cesta, na ktorú odkazuje objekt file je: " + file.getAbsolutePath());

        // ak chceme získať dĺžku(počet bytov) súboru, použijeme metódu length()
        System.out.println("Velkosť súboru example.txt je: " + fileViaString.length()); // 12 -> obsahuje "Hello World!"

        // ak chceme vytvoriť nový priečinok použijeme metódu mkDir()
        File newDir = new File("newDir");
        System.out.println("Existuje priečinok newDir: " + newDir.exists());
        System.out.println("Podarilo sa vytvoriť priečinok newDir: " + newDir.mkdir());;

        // ak chceme vytvoriť nový súbor použijeme metódu createNewFile()
        File newFile = new File(newDir,"newFile.txt");
        System.out.println("Existuje súbor newFile.txt: " + newFile.exists());
        System.out.println("Podarilo sa vytvoriť súbor newFile.txt: " + newFile.createNewFile());

        // ak chceme premenovať súbor alebo adresár, využijeme metódu renameTo(File newFileName)
        // po úspešnom premenovaní, bude objekt na ktorom sme volali metódu renameTo ukazovať na už neexistujúci objekt
        // v tomto prípade objekt newFile bude ukazovať na súbor newFile.txt, ktorý už neexistuje(premenovaný na renamed.txt)
        File renamed = new File(newDir, "renamed.txt");
        System.out.println("Momentálne meno súboru: " + newFile.getName());
        System.out.println("Podarilo sa premenovať súbor newFile.txt na renamed.txt: " + newFile.renameTo(renamed));

        // ak chceme zmazať súbor alebo priečinok, použijeme metódu delete(File file)
        // aby šlo priečinok zmazať, musí byť prázdny
        System.out.println("Podarilo sa zmazať súbor renamed.txt: " + renamed.delete());
        System.out.println("Podarilo sa zmazať priečinok newDir: " + newDir.delete());
    }


}
